//
//  LayoutConstraintView.swift
//  Subviews
//
//  Created by Mark Meretzky on 12/11/14.
//  Copyright (c) 2014 Mark Meretzky. All rights reserved.
//

import UIKit

class LayoutConstraintView: UIView {

	override init(frame aRect: CGRect) {
		super.init(frame: aRect);
		backgroundColor = UIColor.greenColor();
		autoresizingMask = UIViewAutoresizing.FlexibleWidth | UIViewAutoresizing.FlexibleHeight;

		//top left
		var square: Square = Square(frame: CGRectZero);
		square.setTranslatesAutoresizingMaskIntoConstraints(false);
		addSubview(square);

		//Keep the left edge of this square equal to the left edge of this View.

		addConstraint(NSLayoutConstraint(
			item: square,
			attribute: NSLayoutAttribute.Left,
			relatedBy: NSLayoutRelation.Equal,
			toItem: self,
			attribute: NSLayoutAttribute.Left,
			multiplier: 1,
			constant: 0));

		//Keep the top edge of this square equal to the top edge of this View.
		
		addConstraint(NSLayoutConstraint(
			item: square,
			attribute: NSLayoutAttribute.Top,
			relatedBy: NSLayoutRelation.Equal,
			toItem: self,
			attribute: NSLayoutAttribute.Top,
			multiplier: 1,
			constant: 0));
		
		//Keep the width of this square equal to 100.

		addConstraint(NSLayoutConstraint(
			item: square,
			attribute: NSLayoutAttribute.Width,
			relatedBy: NSLayoutRelation.Equal,
			toItem: nil,
			attribute: NSLayoutAttribute.NotAnAttribute,
			multiplier: 0,
			constant: 100));
		
		//Keep the height of this square equal to 100.
		
		addConstraint(NSLayoutConstraint(
			item: square,
			attribute: NSLayoutAttribute.Height,
			relatedBy: NSLayoutRelation.Equal,
			toItem: nil,
			attribute: NSLayoutAttribute.NotAnAttribute,
			multiplier: 0,
			constant: 100));

		//top center
		square = Square(frame: CGRectZero);
		square.setTranslatesAutoresizingMaskIntoConstraints(false);
		addSubview(square);
		
		//Keep the x coordinate of the center of this square
		//equal to the xcoordinate of the center of this view.
		
		addConstraint(NSLayoutConstraint(
			item: square,
			attribute: NSLayoutAttribute.CenterX,
			relatedBy: NSLayoutRelation.Equal,
			toItem: self,
			attribute: NSLayoutAttribute.CenterX,
			multiplier: 1,
			constant: 0));
		
		//Keep the top edge of this square equal to the top edge of this View.
		
		addConstraint(NSLayoutConstraint(
			item: square,
			attribute: NSLayoutAttribute.Top,
			relatedBy: NSLayoutRelation.Equal,
			toItem: self,
			attribute: NSLayoutAttribute.Top,
			multiplier: 1,
			constant: 0));
		
		//Keep the width of this square equal to 100.
		
		addConstraint(NSLayoutConstraint(
			item: square,
			attribute: NSLayoutAttribute.Width,
			relatedBy: NSLayoutRelation.Equal,
			toItem: nil,
			attribute: NSLayoutAttribute.NotAnAttribute,
			multiplier: 0,
			constant: 100));
		
		//Keep the height of this square equal to 100.
		
		addConstraint(NSLayoutConstraint(
			item: square,
			attribute: NSLayoutAttribute.Height,
			relatedBy: NSLayoutRelation.Equal,
			toItem: nil,
			attribute: NSLayoutAttribute.NotAnAttribute,
			multiplier: 0,
			constant: 100));
		
		//top right
		square = Square(frame: CGRectZero);
		square.setTranslatesAutoresizingMaskIntoConstraints(false);
		addSubview(square);
		
		//Keep the right edge of this square equal to the right edge of this View.
		
		addConstraint(NSLayoutConstraint(
			item: square,
			attribute: NSLayoutAttribute.Right,
			relatedBy: NSLayoutRelation.Equal,
			toItem: self,
			attribute: NSLayoutAttribute.Right,
			multiplier: 1,
			constant: 0));
		
		//Keep the top edge of this square equal to the top edge of this View.
		
		addConstraint(NSLayoutConstraint(
			item: square,
			attribute: NSLayoutAttribute.Top,
			relatedBy: NSLayoutRelation.Equal,
			toItem: self,
			attribute: NSLayoutAttribute.Top,
			multiplier: 1,
			constant: 0));
		
		//Keep the width of this square equal to 100.
		
		addConstraint(NSLayoutConstraint(
			item: square,
			attribute: NSLayoutAttribute.Width,
			relatedBy: NSLayoutRelation.Equal,
			toItem: nil,
			attribute: NSLayoutAttribute.NotAnAttribute,
			multiplier: 0,
			constant: 100));
		
		//Keep the height of this square equal to 100.
		
		addConstraint(NSLayoutConstraint(
			item: square,
			attribute: NSLayoutAttribute.Height,
			relatedBy: NSLayoutRelation.Equal,
			toItem: nil,
			attribute: NSLayoutAttribute.NotAnAttribute,
			multiplier: 0,
			constant: 100));
		
		//mid left
		square = Square(frame: CGRectZero);
		square.setTranslatesAutoresizingMaskIntoConstraints(false);
		addSubview(square);
		
		//Keep the left edge of this square equal to the left edge of this View.
		
		addConstraint(NSLayoutConstraint(
			item: square,
			attribute: NSLayoutAttribute.Left,
			relatedBy: NSLayoutRelation.Equal,
			toItem: self,
			attribute: NSLayoutAttribute.Left,
			multiplier: 1,
			constant: 0));
		
		//Keep the y coordinate of the center of this square
		//equal to the y coordinate of this View.
		
		addConstraint(NSLayoutConstraint(
			item: square,
			attribute: NSLayoutAttribute.CenterY,
			relatedBy: NSLayoutRelation.Equal,
			toItem: self,
			attribute: NSLayoutAttribute.CenterY,
			multiplier: 1,
			constant: 0));
		
		//Keep the width of this square equal to 100.
		
		addConstraint(NSLayoutConstraint(
			item: square,
			attribute: NSLayoutAttribute.Width,
			relatedBy: NSLayoutRelation.Equal,
			toItem: nil,
			attribute: NSLayoutAttribute.NotAnAttribute,
			multiplier: 0,
			constant: 100));
		
		//Keep the height of this square equal to 100.
		
		addConstraint(NSLayoutConstraint(
			item: square,
			attribute: NSLayoutAttribute.Height,
			relatedBy: NSLayoutRelation.Equal,
			toItem: nil,
			attribute: NSLayoutAttribute.NotAnAttribute,
			multiplier: 0,
			constant: 100));
		
		//mid center
		square = Square(frame: CGRectZero);
		square.setTranslatesAutoresizingMaskIntoConstraints(false);
		addSubview(square);
		
		//Keep the x coordinate of the center of this square
		//equal to the xcoordinate of the center of this view.
		
		addConstraint(NSLayoutConstraint(
			item: square,
			attribute: NSLayoutAttribute.CenterX,
			relatedBy: NSLayoutRelation.Equal,
			toItem: self,
			attribute: NSLayoutAttribute.CenterX,
			multiplier: 1,
			constant: 0));
		
		//Keep the y coordinate of the center of this square
		//equal to the y coordinate of this View.
		
		addConstraint(NSLayoutConstraint(
			item: square,
			attribute: NSLayoutAttribute.CenterY,
			relatedBy: NSLayoutRelation.Equal,
			toItem: self,
			attribute: NSLayoutAttribute.CenterY,
			multiplier: 1,
			constant: 0));
		
		//Keep the width of this square equal to 100.
		
		addConstraint(NSLayoutConstraint(
			item: square,
			attribute: NSLayoutAttribute.Width,
			relatedBy: NSLayoutRelation.Equal,
			toItem: nil,
			attribute: NSLayoutAttribute.NotAnAttribute,
			multiplier: 0,
			constant: 100));
		
		//Keep the height of this square equal to 100.
		
		addConstraint(NSLayoutConstraint(
			item: square,
			attribute: NSLayoutAttribute.Height,
			relatedBy: NSLayoutRelation.Equal,
			toItem: nil,
			attribute: NSLayoutAttribute.NotAnAttribute,
			multiplier: 0,
			constant: 100));
		
		//mid right
		square = Square(frame: CGRectZero);
		square.setTranslatesAutoresizingMaskIntoConstraints(false);
		addSubview(square);
		
		//Keep the right edge of this square equal to the right edge of this View.
		
		addConstraint(NSLayoutConstraint(
			item: square,
			attribute: NSLayoutAttribute.Right,
			relatedBy: NSLayoutRelation.Equal,
			toItem: self,
			attribute: NSLayoutAttribute.Right,
			multiplier: 1,
			constant: 0));
		
		//Keep the y coordinate of the center of this square
		//equal to the y coordinate of this View.
		
		addConstraint(NSLayoutConstraint(
			item: square,
			attribute: NSLayoutAttribute.CenterY,
			relatedBy: NSLayoutRelation.Equal,
			toItem: self,
			attribute: NSLayoutAttribute.CenterY,
			multiplier: 1,
			constant: 0));
		
		//Keep the width of this square equal to 100.
		
		addConstraint(NSLayoutConstraint(
			item: square,
			attribute: NSLayoutAttribute.Width,
			relatedBy: NSLayoutRelation.Equal,
			toItem: nil,
			attribute: NSLayoutAttribute.NotAnAttribute,
			multiplier: 0,
			constant: 100));
		
		//Keep the height of this square equal to 100.
		
		addConstraint(NSLayoutConstraint(
			item: square,
			attribute: NSLayoutAttribute.Height,
			relatedBy: NSLayoutRelation.Equal,
			toItem: nil,
			attribute: NSLayoutAttribute.NotAnAttribute,
			multiplier: 0,
			constant: 100));
		
		//bottom left
		square = Square(frame: CGRectZero);
		square.setTranslatesAutoresizingMaskIntoConstraints(false);
		addSubview(square);
		
		//Keep the left edge of this square equal to the left edge of this View.
		
		addConstraint(NSLayoutConstraint(
			item: square,
			attribute: NSLayoutAttribute.Left,
			relatedBy: NSLayoutRelation.Equal,
			toItem: self,
			attribute: NSLayoutAttribute.Left,
			multiplier: 1,
			constant: 0));
		
		//Keep the bottom edge of this square equal to the bottom edge of this View.
		
		addConstraint(NSLayoutConstraint(
			item: square,
			attribute: NSLayoutAttribute.Bottom,
			relatedBy: NSLayoutRelation.Equal,
			toItem: self,
			attribute: NSLayoutAttribute.Bottom,
			multiplier: 1,
			constant: 0));
		
		//Keep the width of this square equal to 100.
		
		addConstraint(NSLayoutConstraint(
			item: square,
			attribute: NSLayoutAttribute.Width,
			relatedBy: NSLayoutRelation.Equal,
			toItem: nil,
			attribute: NSLayoutAttribute.NotAnAttribute,
			multiplier: 0,
			constant: 100));
		
		//Keep the height of this square equal to 100.
		
		addConstraint(NSLayoutConstraint(
			item: square,
			attribute: NSLayoutAttribute.Height,
			relatedBy: NSLayoutRelation.Equal,
			toItem: nil,
			attribute: NSLayoutAttribute.NotAnAttribute,
			multiplier: 0,
			constant: 100));
		
		//bottom center
		square = Square(frame: CGRectZero);
		square.setTranslatesAutoresizingMaskIntoConstraints(false);
		addSubview(square);
		
		//Keep the x coordinate of the center of this square
		//equal to the xcoordinate of the center of this view.
		
		addConstraint(NSLayoutConstraint(
			item: square,
			attribute: NSLayoutAttribute.CenterX,
			relatedBy: NSLayoutRelation.Equal,
			toItem: self,
			attribute: NSLayoutAttribute.CenterX,
			multiplier: 1,
			constant: 0));
		
		//Keep the bottom edge of this square equal to the bottom edge of this View.
		
		addConstraint(NSLayoutConstraint(
			item: square,
			attribute: NSLayoutAttribute.Bottom,
			relatedBy: NSLayoutRelation.Equal,
			toItem: self,
			attribute: NSLayoutAttribute.Bottom,
			multiplier: 1,
			constant: 0));
		
		//Keep the width of this square equal to 100.
		
		addConstraint(NSLayoutConstraint(
			item: square,
			attribute: NSLayoutAttribute.Width,
			relatedBy: NSLayoutRelation.Equal,
			toItem: nil,
			attribute: NSLayoutAttribute.NotAnAttribute,
			multiplier: 0,
			constant: 100));
		
		//Keep the height of this square equal to 100.
		
		addConstraint(NSLayoutConstraint(
			item: square,
			attribute: NSLayoutAttribute.Height,
			relatedBy: NSLayoutRelation.Equal,
			toItem: nil,
			attribute: NSLayoutAttribute.NotAnAttribute,
			multiplier: 0,
			constant: 100));
		
		//bottom right
		square = Square(frame: CGRectZero);
		square.setTranslatesAutoresizingMaskIntoConstraints(false);
		addSubview(square);
		
		//Keep the right edge of this square equal to the right edge of this View.
		
		addConstraint(NSLayoutConstraint(
			item: square,
			attribute: NSLayoutAttribute.Right,
			relatedBy: NSLayoutRelation.Equal,
			toItem: self,
			attribute: NSLayoutAttribute.Right,
			multiplier: 1,
			constant: 0));
		
		//Keep the bottom edge of this square equal to the bottom edge of this View.
		
		addConstraint(NSLayoutConstraint(
			item: square,
			attribute: NSLayoutAttribute.Bottom,
			relatedBy: NSLayoutRelation.Equal,
			toItem: self,
			attribute: NSLayoutAttribute.Bottom,
			multiplier: 1,
			constant: 0));

		//Keep the width of this square equal to 100.
		
		addConstraint(NSLayoutConstraint(
			item: square,
			attribute: NSLayoutAttribute.Width,
			relatedBy: NSLayoutRelation.Equal,
			toItem: nil,
			attribute: NSLayoutAttribute.NotAnAttribute,
			multiplier: 0,
			constant: 100));

		//Keep the height of this square equal to 100.
		
		addConstraint(NSLayoutConstraint(
			item: square,
			attribute: NSLayoutAttribute.Height,
			relatedBy: NSLayoutRelation.Equal,
			toItem: nil,
			attribute: NSLayoutAttribute.NotAnAttribute,
			multiplier: 0,
			constant: 100));
	}

	//not called
	required init(coder aDecoder: NSCoder) {
		super.init(coder: aDecoder);
		backgroundColor = UIColor.greenColor();
	}

	/*
	// Only override drawRect: if you perform custom drawing.
	// An empty implementation adversely affects performance during animation.
	override func drawRect(rect: CGRect) {
		// Drawing code
	}
	*/

}
